@@ -1,18 +1,17 @@
 from __future__ import print_function
 
 import io
-import urllib3
-import certifi
 import gzip
 import time
-
 from datetime import timedelta
 from collections import defaultdict
 
+import urllib3
+import certifi
+
 from sentry_sdk.utils import Dsn, logger, capture_internal_exceptions, json_dumps
 from sentry_sdk.worker import BackgroundWorker
 from sentry_sdk.envelope import Envelope, Item, PayloadRef
-
 from sentry_sdk._compat import datetime_utcnow
 from sentry_sdk._types import TYPE_CHECKING
 
@@ -441,12 +440,17 @@ class HttpTransport(Transport):
 
     def _get_pool_options(self, ca_certs):
         # type: (Optional[Any]) -> Dict[str, Any]
-        return {
+        options = {
             "num_pools": self._num_pools,
             "cert_reqs": "CERT_REQUIRED",
             "ca_certs": ca_certs or certifi.where(),
         }
 
+        if self.options["socket_options"]:
+            options["socket_options"] = self.options["socket_options"]
+
+        return options
+
     def _in_no_proxy(self, parsed_dsn):
         # type: (Dsn) -> bool
         no_proxy = getproxies().get("no")
@@ -586,7 +590,7 @@ def make_transport(options):
     elif isinstance(ref_transport, type) and issubclass(ref_transport, Transport):
         transport_cls = ref_transport
     elif callable(ref_transport):
-        return _FunctionTransport(ref_transport)  # type: ignore
+        return _FunctionTransport(ref_transport)
 
     # if a transport class is given only instantiate it if the dsn is not
     # empty or None
